/**-----------------------------------------------------------------------------------------
* Copyright © 2024 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { NgModule } from '@angular/core';
import { ResizeBatchService } from '@progress/kendo-angular-common';
import { CalendarDOMService, CenturyViewService, DecadeViewService, MonthViewService, YearViewService, NavigationService } from '@progress/kendo-angular-dateinputs';
import { DialogContainerService, DialogService, WindowService, WindowContainerService } from '@progress/kendo-angular-dialog';
import { IconsService } from '@progress/kendo-angular-icons';
import { PopupService } from '@progress/kendo-angular-popup';
import { KENDO_GRID_BODY_EXPORTS, KENDO_GRID_COLUMN_MENU_DECLARATIONS, KENDO_GRID_DECLARATIONS, KENDO_GRID_EXPORTS, KENDO_GRID_FILTER_MENU, KENDO_GRID_FILTER_ROW, KENDO_GRID_FOOTER_EXPORTS, KENDO_GRID_GROUP_EXPORTS, KENDO_GRID_HEADER_EXPORTS, KENDO_GRID_PAGER_EXPORTS, KENDO_GRID_SHARED } from './directives';
import { TableDirective } from './column-resizing/table.directive';
import * as i0 from "@angular/core";
import * as i1 from "./grouping/group-header-template.directive";
import * as i2 from "./grouping/group-header-column-template.directive";
import * as i3 from "./grouping/group-footer-template.directive";
import * as i4 from "./grouping/group-header.component";
import * as i5 from "./grouping/group-panel.component";
import * as i6 from "./columns/column.component";
import * as i7 from "./columns/column-group.component";
import * as i8 from "./navigation/logical-cell.directive";
import * as i9 from "./navigation/logical-row.directive";
import * as i10 from "./navigation/focusable.directive";
import * as i11 from "./rendering/footer/footer-template.directive";
import * as i12 from "./rendering/common/col-group.component";
import * as i13 from "./layout/resizable.directive";
import * as i14 from "@progress/kendo-angular-common";
import * as i15 from "./rendering/common/field-accessor.pipe";
import * as i16 from "./rendering/details/detail-template.directive";
import * as i17 from "./columns/span-column.component";
import * as i18 from "./rendering/common/loading.component";
import * as i19 from "./rendering/grid-table.directive";
import * as i20 from "./columns/command-column.component";
import * as i21 from "./columns/checkbox-column.component";
import * as i22 from "./selection/selection-checkbox.directive";
import * as i23 from "./rendering/cell-template.directive";
import * as i24 from "./editing/edit-template.directive";
import * as i25 from "./rendering/table-body.component";
import * as i26 from "./rendering/no-records-template.directive";
import * as i27 from "./rendering/cell.component";
import * as i28 from "./editing/edit-command.directive";
import * as i29 from "./editing/cancel-command.directive";
import * as i30 from "./editing/save-command.directive";
import * as i31 from "./editing/remove-command.directive";
import * as i32 from "./editing/add-command.directive";
import * as i33 from "./rendering/cell-loading.template.directive";
import * as i34 from "./rendering/loading-template.directive";
import * as i35 from "./columns/reorder-column.component";
import * as i36 from "./rendering/header/header.component";
import * as i37 from "./rendering/header/header-template.directive";
import * as i38 from "./column-resizing/column-handle.directive";
import * as i39 from "./selection/selectall-checkbox.directive";
import * as i40 from "./rendering/footer/footer.component";
import * as i41 from "./pager/pager.component";
import * as i42 from "./pager/pager-prev-buttons.component";
import * as i43 from "./pager/pager-next-buttons.component";
import * as i44 from "./pager/pager-numeric-buttons.component";
import * as i45 from "./pager/pager-input.component";
import * as i46 from "./pager/pager-info.component";
import * as i47 from "./pager/pager-page-sizes.component";
import * as i48 from "./pager/pager-template.directive";
import * as i49 from "./pager/pager-dropdown.directive";
import * as i50 from "./pager/pager-input.directive";
import * as i51 from "./filtering/filter-row.component";
import * as i52 from "./filtering/cell/filter-cell.component";
import * as i53 from "./filtering/cell/filter-cell-template.directive";
import * as i54 from "./filtering/cell/string-filter-cell.component";
import * as i55 from "./filtering/cell/numeric-filter-cell.component";
import * as i56 from "./filtering/cell/autocomplete-filter-cell.component";
import * as i57 from "./filtering/cell/boolean-filter-cell.component";
import * as i58 from "./filtering/cell/filter-cell-host.directive";
import * as i59 from "./filtering/cell/filter-cell-wrapper.component";
import * as i60 from "./filtering/cell/date-filter-cell.component";
import * as i61 from "./filtering/cell/filter-cell-operators.component";
import * as i62 from "./filtering/operators/contains-filter-operator.component";
import * as i63 from "./filtering/operators/not-contains-filter-operator.component";
import * as i64 from "./filtering/operators/ends-with-filter-operator.component";
import * as i65 from "./filtering/operators/eq-filter-operator.component";
import * as i66 from "./filtering/operators/is-empty-filter-operator.component";
import * as i67 from "./filtering/operators/is-not-empty-filter-operator.component";
import * as i68 from "./filtering/operators/is-not-null-filter-operator.component";
import * as i69 from "./filtering/operators/isnull-filter-operator.component";
import * as i70 from "./filtering/operators/neq-filter-operator.component";
import * as i71 from "./filtering/operators/starts-with-filter-operator.component";
import * as i72 from "./filtering/operators/gt-filter-operator.component";
import * as i73 from "./filtering/operators/gte-filter-operator.component";
import * as i74 from "./filtering/operators/lt-filter-operator.component";
import * as i75 from "./filtering/operators/lte-filter-operator.component";
import * as i76 from "./filtering/operators/after-filter-operator.component";
import * as i77 from "./filtering/operators/after-eq-filter-operator.component";
import * as i78 from "./filtering/operators/before-eq-filter-operator.component";
import * as i79 from "./filtering/operators/before-filter-operator.component";
import * as i80 from "./filtering/filter-input.directive";
import * as i81 from "./filtering/menu/filter-menu.component";
import * as i82 from "./filtering/menu/filter-menu-container.component";
import * as i83 from "./filtering/menu/filter-menu-input-wrapper.component";
import * as i84 from "./filtering/menu/string-filter-menu-input.component";
import * as i85 from "./filtering/menu/string-filter-menu.component";
import * as i86 from "./filtering/menu/filter-menu-template.directive";
import * as i87 from "./filtering/menu/numeric-filter-menu.component";
import * as i88 from "./filtering/menu/numeric-filter-menu-input.component";
import * as i89 from "./filtering/menu/date-filter-menu-input.component";
import * as i90 from "./filtering/menu/date-filter-menu.component";
import * as i91 from "./filtering/menu/filter-menu-host.directive";
import * as i92 from "./filtering/menu/boolean-filter-menu.component";
import * as i93 from "./filtering/menu/filter-menu-dropdownlist.directive";
import * as i94 from "./filtering/menu/filter-radio-button.directive";
import * as i95 from "./column-menu/column-chooser-item-checked.directive";
import * as i96 from "./column-menu/column-list.component";
import * as i97 from "./column-menu/column-chooser.component";
import * as i98 from "./column-menu/column-menu-chooser.component";
import * as i99 from "./column-menu/column-menu-filter.component";
import * as i100 from "./column-menu/column-menu-item.component";
import * as i101 from "./column-menu/column-menu-item-content-template.directive";
import * as i102 from "./column-menu/column-menu-sort.component";
import * as i103 from "./column-menu/column-menu.component";
import * as i104 from "./column-menu/column-menu-lock.component";
import * as i105 from "./column-menu/column-menu-template.directive";
import * as i106 from "./column-menu/column-menu-container.component";
import * as i107 from "./column-menu/column-menu-item.directive";
import * as i108 from "./column-menu/column-menu-stick.component";
import * as i109 from "./column-menu/column-menu-position.component";
import * as i110 from "./column-menu/column-menu-autosize.component";
import * as i111 from "./column-menu/column-menu-autosize-all.component";
import * as i112 from "./grid.component";
import * as i113 from "./rendering/list.component";
import * as i114 from "./rendering/toolbar/toolbar.component";
import * as i115 from "./localization/localized-messages.directive";
import * as i116 from "./localization/custom-messages.component";
import * as i117 from "./databinding.directive";
import * as i118 from "./rendering/toolbar/toolbar-template.directive";
import * as i119 from "./selection/selection.directive";
import * as i120 from "./editing-directives/template-editing.directive";
import * as i121 from "./editing-directives/reactive-editing.directive";
import * as i122 from "./editing-directives/in-cell-editing.directive";
import * as i123 from "./rendering/details-expand.directive";
import * as i124 from "./rendering/groups-expand.directive";
import * as i125 from "./grouping/group-scroll-binding.directive";
import * as i126 from "./selection/marquee.directive";
import * as i127 from "./rendering/common/spacer.component";
import * as i128 from "./rendering/toolbar/toolbar-focusable.directive";
import * as i129 from "./aggregates/status-bar.component";
import * as i130 from "./aggregates/status-bar-template.directive";
import * as i131 from "./common/clipboard.directive";
// IMPORTANT: NgModule export kept for backwards compatibility
/**
 * Represents the [NgModule](link:site.data.urls.angular['ngmoduleapi'])
 * definition for the Grid component.
 *
 * @example
 *
 * ```ts
 * import { NgModule } from '@angular/core';
 * import { GridModule } from '@progress/kendo-angular-grid';
 * import { BrowserModule } from "@angular/platform-browser";
 * import { AppComponent } from './app.component';
 *
 * @NgModule({
 *     declarations: [AppComponent],
 *     imports:      [BrowserModule, GridModule],
 *     bootstrap:    [AppComponent]
 * })
 * export class AppModule {}
 *
 * ```
 */
export class GridModule {
}
GridModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: GridModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
GridModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: GridModule, imports: [i1.GroupHeaderTemplateDirective, i2.GroupHeaderColumnTemplateDirective, i3.GroupFooterTemplateDirective, i4.GroupHeaderComponent, i5.GroupPanelComponent, i6.ColumnComponent, i7.ColumnGroupComponent, i8.LogicalCellDirective, i9.LogicalRowDirective, i10.FocusableDirective, i11.FooterTemplateDirective, i12.ColGroupComponent, i13.ResizableContainerDirective, i14.TemplateContextDirective, i15.FieldAccessorPipe, i16.DetailTemplateDirective, i17.SpanColumnComponent, i18.LoadingComponent, i19.GridTableDirective, i20.CommandColumnComponent, i21.CheckboxColumnComponent, i22.SelectionCheckboxDirective, i23.CellTemplateDirective, i24.EditTemplateDirective, i25.TableBodyComponent, i26.NoRecordsTemplateDirective, i27.CellComponent, i28.EditCommandDirective, i29.CancelCommandDirective, i30.SaveCommandDirective, i31.RemoveCommandDirective, i32.AddCommandDirective, i33.CellLoadingTemplateDirective, i34.LoadingTemplateDirective, i35.RowReorderColumnComponent, i36.HeaderComponent, i37.HeaderTemplateDirective, i38.ColumnHandleDirective, i39.SelectAllCheckboxDirective, i40.FooterComponent, i41.PagerComponent, i42.PagerPrevButtonsComponent, i43.PagerNextButtonsComponent, i44.PagerNumericButtonsComponent, i45.PagerInputComponent, i46.PagerInfoComponent, i47.PagerPageSizesComponent, i48.PagerTemplateDirective, i49.PagerDropDownListDirective, i50.PagerInputDirective, i51.FilterRowComponent, i52.FilterCellComponent, i53.FilterCellTemplateDirective, i54.StringFilterCellComponent, i55.NumericFilterCellComponent, i56.AutoCompleteFilterCellComponent, i57.BooleanFilterCellComponent, i58.FilterCellHostDirective, i59.FilterCellWrapperComponent, i60.DateFilterCellComponent, i6.ColumnComponent, i7.ColumnGroupComponent, i8.LogicalCellDirective, i9.LogicalRowDirective, i10.FocusableDirective, i11.FooterTemplateDirective, i12.ColGroupComponent, i13.ResizableContainerDirective, i14.TemplateContextDirective, i15.FieldAccessorPipe, i16.DetailTemplateDirective, i17.SpanColumnComponent, i18.LoadingComponent, i19.GridTableDirective, i61.FilterCellOperatorsComponent, i62.ContainsFilterOperatorComponent, i63.DoesNotContainFilterOperatorComponent, i64.EndsWithFilterOperatorComponent, i65.EqualFilterOperatorComponent, i66.IsEmptyFilterOperatorComponent, i67.IsNotEmptyFilterOperatorComponent, i68.IsNotNullFilterOperatorComponent, i69.IsNullFilterOperatorComponent, i70.NotEqualFilterOperatorComponent, i71.StartsWithFilterOperatorComponent, i72.GreaterFilterOperatorComponent, i73.GreaterOrEqualToFilterOperatorComponent, i74.LessFilterOperatorComponent, i75.LessOrEqualToFilterOperatorComponent, i76.AfterFilterOperatorComponent, i77.AfterEqFilterOperatorComponent, i78.BeforeEqFilterOperatorComponent, i79.BeforeFilterOperatorComponent, i80.FilterInputDirective, i6.ColumnComponent, i7.ColumnGroupComponent, i8.LogicalCellDirective, i9.LogicalRowDirective, i10.FocusableDirective, i11.FooterTemplateDirective, i12.ColGroupComponent, i13.ResizableContainerDirective, i14.TemplateContextDirective, i15.FieldAccessorPipe, i16.DetailTemplateDirective, i17.SpanColumnComponent, i18.LoadingComponent, i19.GridTableDirective, i61.FilterCellOperatorsComponent, i62.ContainsFilterOperatorComponent, i63.DoesNotContainFilterOperatorComponent, i64.EndsWithFilterOperatorComponent, i65.EqualFilterOperatorComponent, i66.IsEmptyFilterOperatorComponent, i67.IsNotEmptyFilterOperatorComponent, i68.IsNotNullFilterOperatorComponent, i69.IsNullFilterOperatorComponent, i70.NotEqualFilterOperatorComponent, i71.StartsWithFilterOperatorComponent, i72.GreaterFilterOperatorComponent, i73.GreaterOrEqualToFilterOperatorComponent, i74.LessFilterOperatorComponent, i75.LessOrEqualToFilterOperatorComponent, i76.AfterFilterOperatorComponent, i77.AfterEqFilterOperatorComponent, i78.BeforeEqFilterOperatorComponent, i79.BeforeFilterOperatorComponent, i80.FilterInputDirective, i81.FilterMenuComponent, i82.FilterMenuContainerComponent, i83.FilterMenuInputWrapperComponent, i84.StringFilterMenuInputComponent, i85.StringFilterMenuComponent, i86.FilterMenuTemplateDirective, i87.NumericFilterMenuComponent, i88.NumericFilterMenuInputComponent, i89.DateFilterMenuInputComponent, i90.DateFilterMenuComponent, i91.FilterMenuHostDirective, i92.BooleanFilterMenuComponent, i93.FilterMenuDropDownListDirective, i94.BooleanFilterRadioButtonDirective, i95.ColumnMenuChooserItemCheckedDirective, i96.ColumnListComponent, i97.ColumnChooserComponent, i98.ColumnMenuChooserComponent, i99.ColumnMenuFilterComponent, i100.ColumnMenuItemComponent, i101.ColumnMenuItemContentTemplateDirective, i102.ColumnMenuSortComponent, i103.ColumnMenuComponent, i104.ColumnMenuLockComponent, i105.ColumnMenuTemplateDirective, i106.ColumnMenuContainerComponent, i107.ColumnMenuItemDirective, i108.ColumnMenuStickComponent, i109.ColumnMenuPositionComponent, i110.ColumnMenuAutoSizeColumnComponent, i111.ColumnMenuAutoSizeAllColumnsComponent, i112.GridComponent, i113.ListComponent, i114.ToolbarComponent, i115.LocalizedMessagesDirective, i116.CustomMessagesComponent, i117.DataBindingDirective, i118.ToolbarTemplateDirective, i119.SelectionDirective, i120.TemplateEditingDirective, i121.ReactiveEditingDirective, i122.InCellEditingDirective, i123.ExpandDetailsDirective, i124.ExpandGroupDirective, i125.GroupBindingDirective, i126.GridMarqueeDirective, i127.GridSpacerComponent, i128.GridToolbarFocusableDirective, i129.StatusBarComponent, i130.StatusBarTemplateDirective, i131.GridClipboardDirective, TableDirective], exports: [i112.GridComponent, i118.ToolbarTemplateDirective, i114.ToolbarComponent, i127.GridSpacerComponent, i130.StatusBarTemplateDirective, i117.DataBindingDirective, i119.SelectionDirective, i116.CustomMessagesComponent, i125.GroupBindingDirective, i120.TemplateEditingDirective, i121.ReactiveEditingDirective, i122.InCellEditingDirective, i123.ExpandDetailsDirective, i124.ExpandGroupDirective, i128.GridToolbarFocusableDirective, i1.GroupHeaderTemplateDirective, i2.GroupHeaderColumnTemplateDirective, i3.GroupFooterTemplateDirective, i4.GroupHeaderComponent, i5.GroupPanelComponent, i6.ColumnComponent, i7.ColumnGroupComponent, i8.LogicalCellDirective, i9.LogicalRowDirective, i10.FocusableDirective, i11.FooterTemplateDirective, i12.ColGroupComponent, i13.ResizableContainerDirective, i14.TemplateContextDirective, i15.FieldAccessorPipe, i16.DetailTemplateDirective, i17.SpanColumnComponent, i18.LoadingComponent, i19.GridTableDirective, i20.CommandColumnComponent, i21.CheckboxColumnComponent, i22.SelectionCheckboxDirective, i23.CellTemplateDirective, i24.EditTemplateDirective, i25.TableBodyComponent, i26.NoRecordsTemplateDirective, i27.CellComponent, i28.EditCommandDirective, i29.CancelCommandDirective, i30.SaveCommandDirective, i31.RemoveCommandDirective, i32.AddCommandDirective, i33.CellLoadingTemplateDirective, i34.LoadingTemplateDirective, i35.RowReorderColumnComponent, i36.HeaderComponent, i37.HeaderTemplateDirective, i38.ColumnHandleDirective, i39.SelectAllCheckboxDirective, i41.PagerComponent, i42.PagerPrevButtonsComponent, i43.PagerNextButtonsComponent, i44.PagerNumericButtonsComponent, i45.PagerInputComponent, i46.PagerInfoComponent, i47.PagerPageSizesComponent, i48.PagerTemplateDirective, i49.PagerDropDownListDirective, i50.PagerInputDirective, i51.FilterRowComponent, i52.FilterCellComponent, i53.FilterCellTemplateDirective, i54.StringFilterCellComponent, i55.NumericFilterCellComponent, i56.AutoCompleteFilterCellComponent, i57.BooleanFilterCellComponent, i58.FilterCellHostDirective, i59.FilterCellWrapperComponent, i60.DateFilterCellComponent, i61.FilterCellOperatorsComponent, i62.ContainsFilterOperatorComponent, i63.DoesNotContainFilterOperatorComponent, i64.EndsWithFilterOperatorComponent, i65.EqualFilterOperatorComponent, i66.IsEmptyFilterOperatorComponent, i67.IsNotEmptyFilterOperatorComponent, i68.IsNotNullFilterOperatorComponent, i69.IsNullFilterOperatorComponent, i70.NotEqualFilterOperatorComponent, i71.StartsWithFilterOperatorComponent, i72.GreaterFilterOperatorComponent, i73.GreaterOrEqualToFilterOperatorComponent, i74.LessFilterOperatorComponent, i75.LessOrEqualToFilterOperatorComponent, i76.AfterFilterOperatorComponent, i77.AfterEqFilterOperatorComponent, i78.BeforeEqFilterOperatorComponent, i79.BeforeFilterOperatorComponent, i81.FilterMenuComponent, i82.FilterMenuContainerComponent, i83.FilterMenuInputWrapperComponent, i84.StringFilterMenuInputComponent, i85.StringFilterMenuComponent, i86.FilterMenuTemplateDirective, i87.NumericFilterMenuComponent, i88.NumericFilterMenuInputComponent, i89.DateFilterMenuInputComponent, i90.DateFilterMenuComponent, i91.FilterMenuHostDirective, i92.BooleanFilterMenuComponent, i93.FilterMenuDropDownListDirective, i94.BooleanFilterRadioButtonDirective, i97.ColumnChooserComponent, i99.ColumnMenuFilterComponent, i100.ColumnMenuItemComponent, i101.ColumnMenuItemContentTemplateDirective, i102.ColumnMenuSortComponent, i104.ColumnMenuLockComponent, i108.ColumnMenuStickComponent, i109.ColumnMenuPositionComponent, i98.ColumnMenuChooserComponent, i105.ColumnMenuTemplateDirective, i106.ColumnMenuContainerComponent, i107.ColumnMenuItemDirective, i103.ColumnMenuComponent, i110.ColumnMenuAutoSizeColumnComponent, i111.ColumnMenuAutoSizeAllColumnsComponent, i131.GridClipboardDirective] });
GridModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: GridModule, providers: [
        PopupService,
        ResizeBatchService,
        IconsService,
        DialogContainerService,
        DialogService,
        WindowService,
        WindowContainerService,
        CalendarDOMService,
        CenturyViewService,
        DecadeViewService,
        MonthViewService,
        YearViewService,
        NavigationService
    ], imports: [i4.GroupHeaderComponent, i5.GroupPanelComponent, i6.ColumnComponent, i7.ColumnGroupComponent, i12.ColGroupComponent, i17.SpanColumnComponent, i18.LoadingComponent, i20.CommandColumnComponent, i21.CheckboxColumnComponent, i25.TableBodyComponent, i27.CellComponent, i28.EditCommandDirective, i29.CancelCommandDirective, i30.SaveCommandDirective, i31.RemoveCommandDirective, i32.AddCommandDirective, i35.RowReorderColumnComponent, i36.HeaderComponent, KENDO_GRID_FOOTER_EXPORTS, i41.PagerComponent, i42.PagerPrevButtonsComponent, i43.PagerNextButtonsComponent, i44.PagerNumericButtonsComponent, i45.PagerInputComponent, i46.PagerInfoComponent, i47.PagerPageSizesComponent, i51.FilterRowComponent, i52.FilterCellComponent, i54.StringFilterCellComponent, i55.NumericFilterCellComponent, i56.AutoCompleteFilterCellComponent, i57.BooleanFilterCellComponent, i59.FilterCellWrapperComponent, i60.DateFilterCellComponent, i6.ColumnComponent, i7.ColumnGroupComponent, i12.ColGroupComponent, i17.SpanColumnComponent, i18.LoadingComponent, i61.FilterCellOperatorsComponent, i62.ContainsFilterOperatorComponent, i63.DoesNotContainFilterOperatorComponent, i64.EndsWithFilterOperatorComponent, i65.EqualFilterOperatorComponent, i66.IsEmptyFilterOperatorComponent, i67.IsNotEmptyFilterOperatorComponent, i68.IsNotNullFilterOperatorComponent, i69.IsNullFilterOperatorComponent, i70.NotEqualFilterOperatorComponent, i71.StartsWithFilterOperatorComponent, i72.GreaterFilterOperatorComponent, i73.GreaterOrEqualToFilterOperatorComponent, i74.LessFilterOperatorComponent, i75.LessOrEqualToFilterOperatorComponent, i76.AfterFilterOperatorComponent, i77.AfterEqFilterOperatorComponent, i78.BeforeEqFilterOperatorComponent, i79.BeforeFilterOperatorComponent, i6.ColumnComponent, i7.ColumnGroupComponent, i12.ColGroupComponent, i17.SpanColumnComponent, i18.LoadingComponent, i61.FilterCellOperatorsComponent, i62.ContainsFilterOperatorComponent, i63.DoesNotContainFilterOperatorComponent, i64.EndsWithFilterOperatorComponent, i65.EqualFilterOperatorComponent, i66.IsEmptyFilterOperatorComponent, i67.IsNotEmptyFilterOperatorComponent, i68.IsNotNullFilterOperatorComponent, i69.IsNullFilterOperatorComponent, i70.NotEqualFilterOperatorComponent, i71.StartsWithFilterOperatorComponent, i72.GreaterFilterOperatorComponent, i73.GreaterOrEqualToFilterOperatorComponent, i74.LessFilterOperatorComponent, i75.LessOrEqualToFilterOperatorComponent, i76.AfterFilterOperatorComponent, i77.AfterEqFilterOperatorComponent, i78.BeforeEqFilterOperatorComponent, i79.BeforeFilterOperatorComponent, i81.FilterMenuComponent, i82.FilterMenuContainerComponent, i83.FilterMenuInputWrapperComponent, i84.StringFilterMenuInputComponent, i85.StringFilterMenuComponent, i87.NumericFilterMenuComponent, i88.NumericFilterMenuInputComponent, i89.DateFilterMenuInputComponent, i90.DateFilterMenuComponent, i92.BooleanFilterMenuComponent, i96.ColumnListComponent, i97.ColumnChooserComponent, i98.ColumnMenuChooserComponent, i99.ColumnMenuFilterComponent, i100.ColumnMenuItemComponent, i102.ColumnMenuSortComponent, i103.ColumnMenuComponent, i104.ColumnMenuLockComponent, i106.ColumnMenuContainerComponent, i108.ColumnMenuStickComponent, i109.ColumnMenuPositionComponent, i110.ColumnMenuAutoSizeColumnComponent, i111.ColumnMenuAutoSizeAllColumnsComponent, i112.GridComponent, i113.ListComponent, i114.ToolbarComponent, i116.CustomMessagesComponent, i127.GridSpacerComponent, i129.StatusBarComponent] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: GridModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [...KENDO_GRID_EXPORTS],
                    imports: [
                        ...KENDO_GRID_GROUP_EXPORTS,
                        ...KENDO_GRID_SHARED,
                        ...KENDO_GRID_BODY_EXPORTS,
                        ...KENDO_GRID_HEADER_EXPORTS,
                        ...KENDO_GRID_FOOTER_EXPORTS,
                        ...KENDO_GRID_PAGER_EXPORTS,
                        ...KENDO_GRID_FILTER_ROW,
                        ...KENDO_GRID_FILTER_MENU,
                        ...KENDO_GRID_COLUMN_MENU_DECLARATIONS,
                        ...KENDO_GRID_DECLARATIONS,
                        TableDirective
                    ],
                    providers: [
                        PopupService,
                        ResizeBatchService,
                        IconsService,
                        DialogContainerService,
                        DialogService,
                        WindowService,
                        WindowContainerService,
                        CalendarDOMService,
                        CenturyViewService,
                        DecadeViewService,
                        MonthViewService,
                        YearViewService,
                        NavigationService
                    ]
                }]
        }] });
